prefix mathutils function with aubio_
authorPaul Brossier <piem@altern.org>
Tue, 9 Aug 2005 10:09:36 +0000 (10:09 +0000)
committerPaul Brossier <piem@altern.org>
Tue, 9 Aug 2005 10:09:36 +0000 (10:09 +0000)
examples/tests/test-fft.c
examples/utils.c
src/fft.c
src/mathutils.c
src/mathutils.h
src/onsetdetection.c
src/phasevoc.c
src/pitchdetection.c
src/pitchfcomb.c
src/tss.c
swig/aubio.i

index c61e1b5ae2e47252f06f6dcd9818e643814b607d..e89babef91e9416317ccdb940d83594c8d3e46fb 100644 (file)
@@ -19,7 +19,7 @@ int main(){
         for (i=0; i < channels; i++)
                 spec[i] = AUBIO_ARRAY(fft_data_t,win_s);
         /* initialize the window (see mathutils.c) */
-        window(w,win_s,aubio_win_hanningz);
+        aubio_window(w,win_s,aubio_win_hanningz);
   
         /* fill input with some data */
   
@@ -34,7 +34,7 @@ int main(){
         /* execute inverse fourier transform */
         for (i=0; i < channels; i++) {
                 for (j=0; j<win_s/2+1; j++) {
-                        spec[i][j]  = CEXPC(I*unwrap2pi(fftgrain->phas[i][j]));
+                        spec[i][j]  = CEXPC(I*aubio_unwrap2pi(fftgrain->phas[i][j]));
                         spec[i][j] *= fftgrain->norm[i][j];
                 }
                 aubio_fft_rdo(fft,spec[i],out->data[i],win_s);
index e76af4a4270096172bc28f8b7aa7a116e3e8fc3a..1d1b99e3c23687bc48f6c17568a57466e350e5bc 100644 (file)
@@ -329,7 +329,7 @@ void examples_common_process(aubio_process_func_t process_func, aubio_print_func
 
 void send_noteon(int pitch, int velo)
 {
-    smpl_t mpitch = (FLOOR)(freqtomidi(pitch)+.5);
+    smpl_t mpitch = (FLOOR)(aubio_freqtomidi(pitch)+.5);
     /* we should check if we use midi here, not jack */
 #if ALSA_SUPPORT
     if (usejack) {
index 2e6bf580457e3c6b93e928cae43641fd6917df93..d10cb835a41826f203132d1a60c4b3761c653e7f 100644 (file)
--- a/src/tss.c
+++ b/src/tss.c
@@ -55,7 +55,7 @@ void aubio_tss_do(aubio_tss_t *o, cvec_t * input,
   /* second phase derivative */
   for (i=0;i<channels; i++){
     for (j=0;j<nbins; j++){
-      dev[i][j] = unwrap2pi(input->phas[i][j]
+      dev[i][j] = aubio_unwrap2pi(input->phas[i][j]
           -2.0*theta1[i][j]+theta2[i][j]);
       theta2[i][j] = theta1[i][j];
       theta1[i][j] = input->phas[i][j];
index bc654c2cf8f98dc049a23dc1ae2316bc779430a8..222369166277d6d84964151d9b6f84e9a93e3150 100644 (file)
@@ -97,10 +97,10 @@ typedef enum {
         aubio_win_gaussian,
         aubio_win_welch,
         aubio_win_parzen
-} aubio_window_type_t;
+} aubio_window_type;
 
-void window(smpl_t *w, uint_t size, aubio_window_type_t wintype);
-smpl_t unwrap2pi (smpl_t phase);
+void aubio_window(smpl_t *w, uint_t size, aubio_window_type wintype);
+smpl_t aubio_unwrap2pi (smpl_t phase);
 smpl_t vec_mean(fvec_t *s);
 smpl_t vec_max(fvec_t *s);
 smpl_t vec_min(fvec_t *s);
@@ -118,11 +118,11 @@ void vec_adapt_thres(fvec_t * vec, fvec_t * tmp, uint_t post, uint_t pre);
 smpl_t vec_moving_thres(fvec_t * vec, fvec_t * tmp, uint_t post, uint_t pre, uint_t pos);
 smpl_t vec_median(fvec_t * input);
 smpl_t vec_quadint(fvec_t * x,uint_t pos);
-smpl_t quadfrac(smpl_t s0, smpl_t s1, smpl_t s2, smpl_t pf);
+smpl_t aubio_quadfrac(smpl_t s0, smpl_t s1, smpl_t s2, smpl_t pf);
 uint_t vec_peakpick(fvec_t * input, uint_t pos);
-smpl_t bintomidi(smpl_t bin, smpl_t samplerate, smpl_t fftsize);
-smpl_t bintofreq(smpl_t bin, smpl_t samplerate, smpl_t fftsize);
-smpl_t freqtomidi(smpl_t freq);
+smpl_t aubio_bintomidi(smpl_t bin, smpl_t samplerate, smpl_t fftsize);
+smpl_t aubio_bintofreq(smpl_t bin, smpl_t samplerate, smpl_t fftsize);
+smpl_t aubio_freqtomidi(smpl_t freq);
 uint_t aubio_silence_detection(fvec_t * ibuf, smpl_t threshold);
 smpl_t aubio_level_detection(fvec_t * ibuf, smpl_t threshold);
--- a/src/fft.c
+++ b/src/fft.c
@@ -149,7 +149,7 @@ void aubio_mfft_rdo(aubio_mfft_t * fft,cvec_t * fftgrain, fvec_t * out){
         uint_t i=0,j;
         for (i=0; i < fft->channels; i++) {
                 for (j=0; j<fft->winsize/2+1; j++) {
-                        fft->spec[i][j]  = CEXPC(I*unwrap2pi(fftgrain->phas[i][j]));
+                        fft->spec[i][j]  = CEXPC(I*aubio_unwrap2pi(fftgrain->phas[i][j]));
                         fft->spec[i][j] *= fftgrain->norm[i][j];
                 }
                 aubio_fft_rdo(fft->fft,fft->spec[i],out->data[i],fft->winsize);
index 88dce0484cdb9942fcf14981b6526a131a7d9d25..b523d0ec035bcd263b9184b249390784f46897b5 100644 (file)
@@ -23,7 +23,7 @@
 #include "sample.h"
 #include "mathutils.h"
 
-void window(smpl_t *w, uint_t size, aubio_window_type_t wintype) {
+void aubio_window(smpl_t *w, uint_t size, aubio_window_type wintype) {
   uint_t i;
   switch(wintype) {
     case aubio_win_rectangle:
@@ -73,7 +73,7 @@ void window(smpl_t *w, uint_t size, aubio_window_type_t wintype) {
 }
 
 
-smpl_t unwrap2pi(smpl_t phase) {
+smpl_t aubio_unwrap2pi(smpl_t phase) {
   /* mod(phase+pi,-2pi)+pi */
   return phase + TWO_PI * (1. + floorf(-(phase+PI)/TWO_PI));
 }
@@ -318,7 +318,7 @@ smpl_t vec_quadint(fvec_t * x,uint_t pos) {
     s2 = x->data[0][pos+span];
     /* increase frac */
     for (frac = 0.; frac < 2.; frac = frac + step) {
-      res = quadfrac(s0, s1, s2, frac);
+      res = aubio_quadfrac(s0, s1, s2, frac);
       if (res > resold) 
         resold = res;
       else {                           
@@ -330,7 +330,7 @@ smpl_t vec_quadint(fvec_t * x,uint_t pos) {
   return exactpos;
 }
 
-smpl_t quadfrac(smpl_t s0, smpl_t s1, smpl_t s2, smpl_t pf) {
+smpl_t aubio_quadfrac(smpl_t s0, smpl_t s1, smpl_t s2, smpl_t pf) {
   smpl_t tmp = s0 + (pf/2.) * (pf * ( s0 - 2.*s1 + s2 ) - 3.*s0 + 4.*s1 - s2);
   return tmp;
 }
@@ -344,7 +344,7 @@ uint_t vec_peakpick(fvec_t * onset, uint_t pos) {
        return tmp;
 }
 
-smpl_t freqtomidi(smpl_t freq) {
+smpl_t aubio_freqtomidi(smpl_t freq) {
   smpl_t midi = freq/6.875;
   /* log(freq/A-2)/log(2) */
   midi = LOG(midi)/0.69314718055995;
@@ -353,15 +353,15 @@ smpl_t freqtomidi(smpl_t freq) {
   return midi;
 }
 
-smpl_t bintofreq(smpl_t bin, smpl_t samplerate, smpl_t fftsize) {
+smpl_t aubio_bintofreq(smpl_t bin, smpl_t samplerate, smpl_t fftsize) {
   smpl_t freq = samplerate/fftsize;
   return freq*bin;
 }
 
 
-smpl_t bintomidi(smpl_t bin, smpl_t samplerate, smpl_t fftsize) {
-  smpl_t midi = bintofreq(bin,samplerate,fftsize);
-  return freqtomidi(midi);
+smpl_t aubio_bintomidi(smpl_t bin, smpl_t samplerate, smpl_t fftsize) {
+  smpl_t midi = aubio_bintofreq(bin,samplerate,fftsize);
+  return aubio_freqtomidi(midi);
 }
 
 
index 8925bdc363ae01d3fd0e9e8f0aa3484e5628c6f8..e61855a75fe67f9b535cbcb3c2124a8160e4d7a6 100644 (file)
@@ -103,16 +103,16 @@ typedef enum {
        aubio_win_gaussian,
        aubio_win_welch,
        aubio_win_parzen
-} aubio_window_type_t;
+} aubio_window_type;
 
 /** create window */
-void window(smpl_t *w, uint_t size, aubio_window_type_t wintype);
+void aubio_window(smpl_t *w, uint_t size, aubio_window_type wintype);
 
 /** principal argument
  *
  * mod(phase+PI,-TWO_PI)+PI 
  */
-smpl_t unwrap2pi (smpl_t phase);
+smpl_t aubio_unwrap2pi (smpl_t phase);
 
 /** calculates the mean of a vector
  *
@@ -224,14 +224,14 @@ smpl_t vec_quadint(fvec_t * x,uint_t pos);
  *    \param s0,s1,s2 are 3 known points on the curve,
  *    \param pf is the floating point index [0;2]
  */
-smpl_t quadfrac(smpl_t s0, smpl_t s1, smpl_t s2, smpl_t pf);
+smpl_t aubio_quadfrac(smpl_t s0, smpl_t s1, smpl_t s2, smpl_t pf);
 
 /** returns 1 if X1 is a peak and positive */
 uint_t vec_peakpick(fvec_t * input, uint_t pos);
 
-smpl_t bintomidi(smpl_t bin, smpl_t samplerate, smpl_t fftsize);
-smpl_t bintofreq(smpl_t bin, smpl_t samplerate, smpl_t fftsize);
-smpl_t freqtomidi(smpl_t freq);
+smpl_t aubio_bintomidi(smpl_t bin, smpl_t samplerate, smpl_t fftsize);
+smpl_t aubio_bintofreq(smpl_t bin, smpl_t samplerate, smpl_t fftsize);
+smpl_t aubio_freqtomidi(smpl_t freq);
 
 uint_t aubio_silence_detection(fvec_t * ibuf, smpl_t threshold);
 smpl_t aubio_level_detection(fvec_t * ibuf, smpl_t threshold);
index 8810e8b39c30f2e39f1bbc692f4a36767b74a9c4..6111e8e7729c1e18cb39c122812385d1a62afe83 100644 (file)
@@ -73,7 +73,7 @@ void aubio_onsetdetection_complex (aubio_onsetdetection_t *o, cvec_t * fftgrain,
        for (i=0;i<fftgrain->channels; i++)     {
                onset->data[i][0] = 0.;
                for (j=0;j<nbins; j++)  {
-                       o->dev1->data[i][j]      = unwrap2pi(
+                       o->dev1->data[i][j]      = aubio_unwrap2pi(
                                        fftgrain->phas[i][j]
                                        -2.0*o->theta1->data[i][j]+
                                        o->theta2->data[i][j]);
@@ -103,7 +103,7 @@ void aubio_onsetdetection_phase(aubio_onsetdetection_t *o,
                o->dev1->data[i][0]=0.;
                for ( j=0;j<nbins; j++ )        {
                        o->dev1->data[i][j] = 
-                               unwrap2pi(
+                               aubio_unwrap2pi(
                                                fftgrain->phas[i][j]
                                                -2.0*o->theta1->data[i][j]
                                                +o->theta2->data[i][j]);
index d25dbaa80374298623b882042ec1250c28bfceee..aae7ea599ff80527c2c2ddd3cca36b16f239798e 100644 (file)
@@ -113,7 +113,7 @@ aubio_pvoc_t * new_aubio_pvoc (uint_t win_s, uint_t hop_s, uint_t channels) {
        pv->dataold  = new_fvec  (win_s-hop_s, channels);
        pv->synthold = new_fvec (win_s-hop_s, channels);
        pv->w        = AUBIO_ARRAY(smpl_t,win_s);
-       window(pv->w,win_s,aubio_win_hanningz);
+       aubio_window(pv->w,win_s,aubio_win_hanningz);
 
        pv->channels = channels;
        pv->hop_s    = hop_s;
index fec2c2428182ca443b943074fdd8dac1f2324bfd..1093b4786cb1167e2771de19d815904bd08c75d9 100644 (file)
@@ -138,9 +138,9 @@ smpl_t aubio_pitchdetection_mcomb(aubio_pitchdetection_t *p, fvec_t *ibuf) {
        smpl_t pitch = 0.;
         aubio_pvoc_do(p->pv,ibuf,p->fftgrain);
         pitch = aubio_pitchmcomb_detect(p->mcomb,p->fftgrain);
/** \bug should move the >0 check within bintofreq */
         if (pitch>0.) {
-                pitch = bintofreq(pitch,p->srate,p->bufsize);
+                pitch = aubio_bintofreq(pitch,p->srate,p->bufsize);
         } else {
                 pitch = 0.;
         }
index fccf955751497a19a0bb26aa5b703bfebfc6f4ce..db00febb85a490f64e259dcddc827488d8fec05f 100644 (file)
@@ -90,7 +90,7 @@ smpl_t aubio_pitchfcomb_detect (aubio_pitchfcomb_t * p, fvec_t * input)
     tmp -= (smpl_t)k*phaseDifference;
 
     /* map delta phase into +/- Pi interval */
-    tmp = unwrap2pi(tmp);
+    tmp = aubio_unwrap2pi(tmp);
 
     /* get deviation from bin frequency from the +/- Pi interval */
     tmp = p->fftSize/input->length*tmp/(TWO_PI);
@@ -138,9 +138,9 @@ smpl_t aubio_pitchdetection_mcomb(aubio_pitchdetection_t *p, fvec_t *ibuf) {
         aubio_pvoc_do(p->pv,ibuf,p->fftgrain);
         pitch = aubio_pitchmcomb_detect(p->mcomb,p->fftgrain);
-        /** \bug should move the >0 check within bintofreq */
+        /** \bug should move the >0 check within aubio_bintofreq */
         if (pitch>0.) {
index dcbe2365f0c1512e6ad3180a4cf3134222949c14..768a433f07e5af76e51ef85a013c81201f11b50d 100644 (file)